@@ -2061,7 +2061,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
             return
         caps = msg.args[2].split()
         assert caps, 'Empty list of capabilities'
-        log.debug('%s: Server acknowledged capabilities: %L',
+        log.debug('%s: Server acknowledged capabilities: %s',
                  self.network, caps)
         self.state.capabilities_ack.update(caps)
 
@@ -2074,16 +2074,18 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
         caps = msg.args[2].split()
         assert caps, 'Empty list of capabilities'
         self.state.capabilities_nak.update(caps)
-        log.warning('%s: Server refused capabilities: %L',
+        log.warning('%s: Server refused capabilities: %s',
                     self.network, caps)
         self.capUpkeep(msg)
 
     def _onCapSts(self, policy, msg):
+        tls_connection = self.driver.currentServer.force_tls_verification \
+            or self.driver.ssl
         secure_connection = self.driver.currentServer.force_tls_verification \
             or (self.driver.ssl and self.driver.anyCertValidationEnabled())
 
         parsed_policy = ircutils.parseStsPolicy(
-            log, policy, secure_connection=secure_connection)
+            log, policy, tls_connection=tls_connection)
         if parsed_policy is None:
             # There was an error (and it was logged). Ignore it and proceed
             # with the connection.
@@ -2106,11 +2108,28 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
                 self.driver.currentServer.hostname,
                 self.driver.currentServer.port,
                 policy)
+        elif self.driver.ssl:
+            # SSL enabled, but certificates are not checked -> reconnect on the
+            # same port and check certificates, before storing the STS policy.
+            hostname = self.driver.currentServer.hostname
+            port = self.driver.currentServer.port
+            attempt = self.driver.currentServer.attempt
+
+            log.info('Got STS policy over insecure TLS connection; '
+                     'reconnecting to check certificates. %r',
+                     self.driver.currentServer)
+            # Reconnect to the server, but with TLS *and* certificate
+            # validation this time.
+            self.state.fsm.on_shutdown(self, msg)
+
+            self.driver.reconnect(
+                server=Server(hostname, port, attempt, True),
+                wait=True)
         else:
             hostname = self.driver.currentServer.hostname
             attempt = self.driver.currentServer.attempt
 
-            log.info('Got STS policy over insecure connection; '
+            log.info('Got STS policy over insecure (cleartext) connection; '
                      'reconnecting to secure port. %r',
                      self.driver.currentServer)
             # Reconnect to the server, but with TLS *and* certificate
